@@ -1,6 +1,7 @@
 from django.contrib import admin
 from django import forms
 from django.utils.translation import ugettext_lazy as _
+from django.conf import settings
 
 from parler.admin import TranslatableAdmin
 from parler.forms import TranslatableModelForm
@@ -18,7 +19,7 @@ __all__ = (
 
 class TemplateForm(TranslatableModelForm):
     html = forms.CharField(
-        widget=get_html_field_widget()
+        widget=get_html_field_widget(), required=False
     )
     context = forms.CharField(
         label=_('Context'), widget=forms.Textarea(), disabled=True,
@@ -60,6 +61,23 @@ class TemplateAdmin(TranslatableAdmin):
             'fields': [
                 'subject', 'html', 'context', 'plain'
             ]
+        }),
+    )
+    tilda_fieldsets = (
+        (None, {
+            'fields': [
+                'name', 'event',
+            ]
+        }),
+        (_('Template'), {
+            'fields': [
+                'subject', 'html', 'context', 'plain'
+            ]
+        }),
+        (_('Integrations'), {
+            'fields': [
+                'tilda_id'
+            ]
         })
     )
     add_fieldsets = (
@@ -74,6 +92,9 @@ class TemplateAdmin(TranslatableAdmin):
         if not obj:
             return self.add_fieldsets
 
+        if 'postie.integrations.tilda' in settings.INSTALLED_APPS:
+            return self.tilda_fieldsets
+
         return super().get_fieldsets(request, obj)
 
     def get_form(self, request, obj=None, **kwargs):
