@@ -51,6 +51,18 @@ class Template(TranslatableModel):
                 'Write variables inside {{  }}.',
             ),
             blank=True, null=True
+        ),
+        # Tilda integration fields
+        tilda_id=models.PositiveIntegerField(
+            verbose_name=_('Tilda id'), blank=True, null=True,
+            help_text=_(
+                'If not empty `HTML` field will be not used anymore, '
+                'intead tilda page will be'
+            )
+        ),
+        tilda_html=models.TextField(
+            verbose_name=_('Tilda HTML'), editable=False, blank=True,
+            null=True
         )
     )
 
@@ -61,6 +73,12 @@ class Template(TranslatableModel):
     def __str__(self) -> str:
         return self.name
 
+    def get_html(self) -> str:
+        if self.tilda_id:
+            return self.tilda_html or self.html
+
+        return self.html
+
 
 class Letter(TimeStampedModel, models.Model):
     """Mail letter model.
@@ -97,8 +115,8 @@ class Letter(TimeStampedModel, models.Model):
     )
 
     status = models.CharField(
-        verbose_name=_('Status'), max_length=255, choices=LETTER_STATUSES,
-        default=LETTER_STATUSES.draft
+        verbose_name=_('Status'), max_length=255,
+        choices=LETTER_STATUSES, default=LETTER_STATUSES.draft
     )
     language = models.CharField(
         verbose_name=_('Language'), max_length=127, blank=True, null=True
