@@ -19,6 +19,8 @@ ROOT_URLCONF = 'postie.tests.urls'
 
 INSTALLED_APPS = (
     'postie',
+    'postie.integrations.tilda',
+    'solo',
     'codemirror2',
     'ckeditor',
     'parler',
